@@ -1,3 +1,6 @@
+"""
+Base class for shared websocket endpoints
+"""
 from __future__ import annotations
 
 import logging
@@ -35,8 +38,17 @@ class WebSocketMessageEndpoint(ABC):
 
     @abstractmethod
     async def on_receive(self, route: str, data: typing.Any) -> bool:
-        """Override to handle an incoming websocket message"""
+        """
+        Override to handle an incoming websocket message
+
+        :param route: The route string to match
+        :param data: The incoming data
+        """
 
     async def on_disconnect(self, close_code: int) -> None:
-        """Override to handle a disconnecting websocket"""
+        """
+        Override to handle a disconnecting websocket
+
+        :param close_code: The code for the socket disconnect
+        """
 
